<?php

use WooDostavista\View\JsonResponse;
use WooDostavista\Warehouses\WarehouseManager;

defined('ABSPATH') || exit;

class WC_Dostavista_Nearest_Warehouse_Controller
{
    public static function get_nearest_warehouse()
    {
        global $wpdb;

        $postBody = file_get_contents('php://input');
        $data     = json_decode($postBody, true) ?? [];

        if (!$data) {
            (new JsonResponse(['error' => 'required_post_data'], 500))->render();
            exit();
        }

        $address = (trim(urldecode($data['address'])) ?? null);

        if (!$address) {
            (new JsonResponse(['error' => 'required_address'], 500))->render();
            exit();
        }

        $warehouseManager = new WarehouseManager($wpdb);

        $dvServiceLocator = WC_Dostavista_Service_Locator::getInstance();

        $geoCoderService = $dvServiceLocator->getGeoCoderService();

        $nearestWarehouse = $warehouseManager->getNearestWarehouseByAddress(
            $address,
            $geoCoderService
        );

        (new JsonResponse(
            [
                'is_successfully' => true,
                'warehouse'     => $nearestWarehouse
                ? [
                        'id'      => $nearestWarehouse->id,
                        'address' => $nearestWarehouse->getFullAddress(),
                ]
                : null,
            ]
        ))->render();
    }
}
