<?php

use WooDostavista\DvCmsModuleApiClient\DvCmsModuleApiClient;
use WooDostavista\GeneralCache\Cache;
use WooDostavista\GeoCoder\GeoCoderService;
use WooDostavista\GeoCoder\GeoSuggestion\GeoSuggestionService;
use WooDostavista\GeoCoder\Providers\DadataGeoCoderClient;
use WooDostavista\GeoCoder\Providers\DostavistaGeoCoderClient;
use WooDostavista\GeoCoder\Providers\GeoProvidersEnum;
use WooDostavista\Http\HttpClient;
use WooDostavista\ModuleConfig\ModuleConfig;
use WooDostavista\ModuleSettings\ModuleSettings;

class WC_Dostavista_Service_Locator
{
    /** @var self */
    private static $_instance;

    /** @var wpdb $wpdb */
    private static $_wpdb;

    /** @var GeoCoderService|null */
    private $geoCoderService = null;

    /** @var DadataGeoCoderClient|null */
    private $dadataGeoCoderClient = null;

    /** @var DostavistaGeoCoderClient|null */
    private $dostavistaGeoCoderClient = null;

    /** @var GeoSuggestionService|null */
    private $geoSuggestionService = null;

    /** @var null|DvCmsModuleApiClient */
    private $dvCmsModuleApiClient = null;

    private function __construct(wpdb $wpdb)
    {
        self::$_wpdb = $wpdb;
    }

    public static function getInstance(): self
    {
        global $wpdb;

        if (self::$_instance === null) {
            self::$_instance = new self($wpdb);
        }

        return self::$_instance;
    }

    private function __clone()
    {
    }

    private function __wakeup()
    {
    }

    public function getGeoCoderService(): GeoCoderService
    {
        if ($this->geoCoderService) {
            return $this->geoCoderService;
        }

        $cache      = new Cache(self::$_wpdb);
        $config     = new ModuleConfig();

        $geoCoderProvider = null;

        switch ($config->getGeoCoderProvider()) {
            case GeoProvidersEnum::PROVIDER_DOSTAVISTA:
                $geoCoderProvider = $this->getDostavistaGeoCoderClient();
                break;
            case GeoProvidersEnum::PROVIDER_DADATA:
                $geoCoderProvider = $this->getDadataGeoCoderClient();
                break;
        }

        $this->geoCoderService = new GeoCoderService($geoCoderProvider, $cache);

        return $this->geoCoderService;
    }

    /**
     * @return DadataGeoCoderClient|null
     */
    public function getDadataGeoCoderClient()
    {
        if ($this->dadataGeoCoderClient) {
            return $this->dadataGeoCoderClient;
        }

        $httpClient = new HttpClient();
        $config     = new ModuleConfig();

        $this->dadataGeoCoderClient = $config->getDadataToken()
            ? new DadataGeoCoderClient($httpClient, $config->getDadataToken())
            : null;

        return $this->dadataGeoCoderClient;
    }

    /**
     * @return DostavistaGeoCoderClient|null
     */
    public function getDostavistaGeoCoderClient()
    {
        if ($this->dostavistaGeoCoderClient) {
            return $this->dostavistaGeoCoderClient;
        }

        $dvCmsModuleApiClient = $this->getDvCmsModuleApiClient();

        $this->dostavistaGeoCoderClient = new DostavistaGeoCoderClient($dvCmsModuleApiClient);

        return $this->dostavistaGeoCoderClient;
    }

    /**
     * @return DvCmsModuleApiClient|null
     */
    public function getDvCmsModuleApiClient()
    {
        if ($this->dvCmsModuleApiClient) {
            return $this->dvCmsModuleApiClient;
        }

        $settings = new ModuleSettings(self::$_wpdb);

        $this->dvCmsModuleApiClient = new DvCmsModuleApiClient(
            $settings->getApiUrl(), $settings->getAuthToken()
        );

        return $this->dvCmsModuleApiClient;
    }

    /**
     * @return GeoSuggestionService|null
     */
    public function getGeoSuggestionService()
    {
        if ($this->geoSuggestionService) {
            return $this->geoSuggestionService;
        }

        $cache = new Cache(self::$_wpdb);

        $this->geoSuggestionService = new GeoSuggestionService(
            $this->getDostavistaGeoCoderClient(),
            $cache
        );

        return $this->geoSuggestionService;
    }
}
