<?php

namespace WooDostavista\GeoCoder\Providers;

use WooDostavista\DvCmsModuleApiClient\DvCmsModuleApiClient;
use WooDostavista\DvCmsModuleApiClient\DvCmsModuleApiHttpException;
use WooDostavista\GeoCoder\GeoCoderHttpException;
use WooDostavista\GeoCoder\GeoCoderInterface;
use WooDostavista\GeoCoder\GeoPoint;
use WooDostavista\GeoCoder\GeoSuggestion\GeoSuggessionInterface;
use WooDostavista\GeoCoder\GeoSuggestion\GeoSuggestionAddress;
use WooDostavista\Http\HttpClientException;

class DostavistaGeoCoderClient implements GeoSuggessionInterface, GeoCoderInterface
{
    /** @var DvCmsModuleApiClient  */
    private $dvApiClient;

    public function __construct(DvCmsModuleApiClient $dvApiClient)
    {
        $this->dvApiClient = $dvApiClient;
    }

    /**
     * @return GeoSuggestionAddress[]
     */
    public function getSuggestionsByAddress(string $address): array
    {
        $dostavistaAddressSuggestionsResponseModels = [];

        try {
            $dostavistaAddressSuggestionsResponseModels = $this->dvApiClient->getGeoSuggestions($address);
        } catch (\Exception $httpClientException) {
            throw new GeoCoderHttpException(
                $httpClientException->getMessage(), $httpClientException->getCode(), $httpClientException
            );
        }

        $points = [];
        foreach ($dostavistaAddressSuggestionsResponseModels as $addressSuggestionsResponseModel) {
            $points[] = new GeoSuggestionAddress(
                $addressSuggestionsResponseModel->getFormatedAddress(),
                $addressSuggestionsResponseModel->getCityLevelAddress(),
                $addressSuggestionsResponseModel->getStreetLevelAddress()
            );
        }

        return $points;
    }

    /**
     * @return GeoPoint|null
     */
    public function getGeoPointByAddress(string $address)
    {
        $geoPoint = null;

        try {
            $geoPoint = $this->dvApiClient->geocode(trim($address));
        } catch (DvCmsModuleApiHttpException $exception) {

        }

        return $geoPoint;
    }
}
